@@ -2,6 +2,7 @@
 import os
 from PIL import Image
 import math
+import copy
 
 from django.db import models
 from django.conf import settings
@@ -923,7 +924,7 @@ class WordToken(models.Model):
 
     def getAnalysisLines(self,form):
         if self.Output is not None:
-            outline = copy(self.Output)
+            outline = copy.copy(self.Output)
         else:
             outline = {}
         wanted_fields =[]
